==> jc-1.4.0.tar.gz: java/security/spec/RSAPrivateCrtKeySpec.h <==
// public class java.security.spec.RSAPrivateCrtKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9739dee73a389d94 java_security_spec_RSAPrivateCrtKeySpec
// @dep_class 47d1dcfa807306d7 java_security_spec_RSAPrivateKeySpec

// header file dependencies
// @dep_header java_security_spec_RSAPrivateKeySpec

#include "java/security/spec/RSAPrivateKeySpec.h"

#ifndef _JC_java_security_spec_RSAPrivateCrtKeySpec_H_
#define _JC_java_security_spec_RSAPrivateCrtKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs	_jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs	_jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$refs	_jc_java_security_spec_RSAPrivateCrtKeySpec$refs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs	_jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object	_jc_java_security_spec_RSAPrivateCrtKeySpec$object;

typedef const struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods	_jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtable	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtype	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAPrivateCrtKeySpec$method$_init$61d41c6df3047b16(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getCrtCoefficient$3b26e563f0a78fa8(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeExponentP$7b86450f402ae888(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeExponentQ$1768ae9fab37aad8(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeP$9033505b0ccf417d(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeQ$bf448ca4ce4c7a9b(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getCrtCoefficient$3b26e563f0a78fa8;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeExponentP$7b86450f402ae888;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeExponentQ$1768ae9fab37aad8;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeP$9033505b0ccf417d;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeQ$bf448ca4ce4c7a9b;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getCrtCoefficient$3b26e563f0a78fa8)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentP$7b86450f402ae888)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentQ$1768ae9fab37aad8)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeP$9033505b0ccf417d)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrimeQ$bf448ca4ce4c7a9b)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *);
};

// Vtable
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPrivateKeySpec$vmethods	java_security_spec_RSAPrivateKeySpec;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods	java_security_spec_RSAPrivateCrtKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*publicExponent;
	struct _jc_java_math_BigInteger$object	*primeP;
	struct _jc_java_math_BigInteger$object	*primeQ;
	struct _jc_java_math_BigInteger$object	*primeExponentP;
	struct _jc_java_math_BigInteger$object	*primeExponentQ;
	struct _jc_java_math_BigInteger$object	*crtCoefficient;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$refs {
    _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs	java_security_spec_RSAPrivateCrtKeySpec;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs	java_security_spec_RSAPrivateCrtKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object {
	_jc_java_security_spec_RSAPrivateCrtKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAPrivateCrtKeySpec$vtype _jc_java_security_spec_RSAPrivateCrtKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAPrivateCrtKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAPrivateCrtKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAPrivateCrtKeySpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/RSAPrivateCrtKeySpec.h <==
// public class java.security.spec.RSAPrivateCrtKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9739dee73a389d94 java_security_spec_RSAPrivateCrtKeySpec
// @dep_class 47d1dcfa807306d7 java_security_spec_RSAPrivateKeySpec

// header file dependencies
// @dep_header java_security_spec_RSAPrivateKeySpec

#include "java/security/spec/RSAPrivateKeySpec.h"

#ifndef _JC_java_security_spec_RSAPrivateCrtKeySpec_H_
#define _JC_java_security_spec_RSAPrivateCrtKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs	_jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs	_jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$refs	_jc_java_security_spec_RSAPrivateCrtKeySpec$refs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs	_jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object	_jc_java_security_spec_RSAPrivateCrtKeySpec$object;

typedef const struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods	_jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtable	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtype	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAPrivateCrtKeySpec$method$_init$61d41c6df3047b16(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getCrtCoefficient$3b26e563f0a78fa8(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeExponentP$7b86450f402ae888(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeExponentQ$1768ae9fab37aad8(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeP$9033505b0ccf417d(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPrimeQ$bf448ca4ce4c7a9b(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateCrtKeySpec$method$getPublicExponent$6a90dc2525ab30b7(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getCrtCoefficient$3b26e563f0a78fa8;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeExponentP$7b86450f402ae888;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeExponentQ$1768ae9fab37aad8;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeP$9033505b0ccf417d;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPrimeQ$bf448ca4ce4c7a9b;
extern _jc_method _jc_java_security_spec_RSAPrivateCrtKeySpec$method_info$getPublicExponent$6a90dc2525ab30b7;

// Virtual methods structure
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getCrtCoefficient$3b26e563f0a78fa8)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentP$7b86450f402ae888)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeExponentQ$1768ae9fab37aad8)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeP$9033505b0ccf417d)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrimeQ$bf448ca4ce4c7a9b)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPublicExponent$6a90dc2525ab30b7)(_jc_env *, struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPrivateKeySpec$vmethods	java_security_spec_RSAPrivateKeySpec;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$vmethods	java_security_spec_RSAPrivateCrtKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*publicExponent;
	struct _jc_java_math_BigInteger$object	*primeP;
	struct _jc_java_math_BigInteger$object	*primeQ;
	struct _jc_java_math_BigInteger$object	*primeExponentP;
	struct _jc_java_math_BigInteger$object	*primeExponentQ;
	struct _jc_java_math_BigInteger$object	*crtCoefficient;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$refs {
    _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_refs	java_security_spec_RSAPrivateCrtKeySpec;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_security_spec_RSAPrivateCrtKeySpec$sub_nonrefs	java_security_spec_RSAPrivateCrtKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAPrivateCrtKeySpec$object {
	_jc_java_security_spec_RSAPrivateCrtKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAPrivateCrtKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAPrivateCrtKeySpec$vtype _jc_java_security_spec_RSAPrivateCrtKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAPrivateCrtKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAPrivateCrtKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAPrivateCrtKeySpec_H_ */
